@@ -31,10 +31,13 @@ class Client(object):
     A snap7 client
     """
     def __init__(self):
-        self.library = load_library()
         self.pointer = False
+        self.library = load_library()
         self.create()
 
+    def __del__(self):
+        self.destroy()
+        
     def create(self):
         """
         create a SNAP7 client.
@@ -69,7 +72,7 @@ class Client(object):
         hot starts a client
         """
         logger.info("hot starting plc")
-        return self.library.Cli_PlcColdStart(self.pointer)
+        return self.library.Cli_PlcHotStart(self.pointer)
 
     def get_cpu_state(self):
         """
@@ -293,7 +296,10 @@ class Client(object):
         logging.debug("listing blocks of type: %s size: %s" %
                       (blocktype, size))
 
-        data = (c_int * 10)()
+        if (size == 0):
+            return 0
+		
+        data = (c_uint16 * size)()
         count = c_int(size)
         result = self.library.Cli_ListBlocksOfType(
             self.pointer, blocktype,
@@ -554,4 +560,4 @@ class Client(object):
         code = self.library.Cli_GetPduLength(self.pointer, byref(requested_), byref(negotiated_))
         check_error(code)
 
-        return negotiated_.value
\ No newline at end of file
+        return negotiated_.value
